@@ -28,6 +28,8 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.StringTokenizer;
 import java.util.TreeSet;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 import org.apache.maven.artifact.repository.ArtifactRepository;
 import org.apache.maven.model.Developer;
@@ -156,6 +158,13 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
      */
     protected boolean generateJavadoc;
 
+    /**
+     * The packaging helper used to build the package (CDBS or DH).
+     *
+     * @parameter expression="${helper}" default-value="dh"
+     */
+    protected String helper;
+
     private PackageScanner scanner = new PackageScanner(false);
     private LicensesScanner licensesScanner = new LicensesScanner();
 
@@ -167,6 +176,9 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
 
         String controlTemplate = "control.vm";
         String rulesTemplate = "rules.vm";
+        if ("cdbs".equals(helper)) {
+            rulesTemplate = "rules.cdbs.vm";
+        }
         if ("ant".equals(packageType)) {
             controlTemplate = "control.ant.vm";
             rulesTemplate = "rules.ant.vm";
@@ -185,6 +197,7 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
             context.put("package", packageName);
             context.put("packageType", packageType);
             context.put("binPackage", binPackageName);
+            context.put("helper", helper);
             context.put("packager", packager);
             context.put("packagerEmail", email);
             context.put("project", project);
@@ -402,6 +415,20 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
                 }
             }
 
+            if (downloadUrl != null && downloadUrl.startsWith("scm:git:") && downloadUrl.contains("github")) {
+                Pattern pattern = Pattern.compile("github\\.com/([^/]+)/([^/\\.]+)");
+                Matcher matcher = pattern.matcher(downloadUrl);
+                if (matcher.find()) {
+                    downloadType = DownloadType.GITHUB;
+                    downloadUrl = downloadUrl.substring("scm:git:".length());
+
+                    context.put("userId", matcher.group(1));
+                    context.put("repository", matcher.group(2));
+
+                    generateFile(context, "watch.github.vm", outputDirectory, "watch");
+                }
+            }
+
             if (downloadType == DownloadType.UNKNOWN) {
                 System.err.println("Cannot recognize the download url (" +
                         downloadUrl + ").");
@@ -602,6 +629,7 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
         int SVN = 1;
         int CVS = 2;
         int TARBALL = 3;
+        int GITHUB = 4;
     }
 }
 
